package cn.com.infosec.jce;

import cn.com.infosec.asn1.ASN1InputStream;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.ASN1Set;
import cn.com.infosec.asn1.DERBitString;
import cn.com.infosec.asn1.DEREncodable;
import cn.com.infosec.asn1.DERInteger;
import cn.com.infosec.asn1.DERNull;
import cn.com.infosec.asn1.DERObjectIdentifier;
import cn.com.infosec.asn1.DEROutputStream;
import cn.com.infosec.asn1.cryptopro.CryptoProObjectIdentifiers;
import cn.com.infosec.asn1.nist.NISTObjectIdentifiers;
import cn.com.infosec.asn1.oiw.OIWObjectIdentifiers;
import cn.com.infosec.asn1.pkcs.CertificationRequest;
import cn.com.infosec.asn1.pkcs.CertificationRequestInfo;
import cn.com.infosec.asn1.pkcs.PKCSObjectIdentifiers;
import cn.com.infosec.asn1.pkcs.RSASSAPSSparams;
import cn.com.infosec.asn1.teletrust.TeleTrusTObjectIdentifiers;
import cn.com.infosec.asn1.x509.AlgorithmIdentifier;
import cn.com.infosec.asn1.x509.SubjectPublicKeyInfo;
import cn.com.infosec.asn1.x509.X509Name;
import cn.com.infosec.asn1.x9.X9ObjectIdentifiers;
import cn.com.infosec.util.Strings;
import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.security.InvalidKeyException;
import java.security.KeyFactory;
import java.security.NoSuchAlgorithmException;
import java.security.PrivateKey;
import java.security.PublicKey;
import java.security.Signature;
import java.security.SignatureException;
import java.security.spec.InvalidKeySpecException;
import java.security.spec.X509EncodedKeySpec;
import java.util.HashSet;
import java.util.Hashtable;
import java.util.Set;
import javax.security.auth.x500.X500Principal;

public class PKCS10CertificationRequest extends CertificationRequest {
   private static Hashtable algorithms = new Hashtable();
   private static Hashtable keyAlgorithms = new Hashtable();
   private static Set noParams = new HashSet();
   private static Hashtable oids = new Hashtable();
   private static Hashtable params = new Hashtable();
   // $FF: synthetic field
   static Class class$0;

   static {
      Hashtable var10000 = algorithms;
      DERObjectIdentifier var0;
      var0 = new DERObjectIdentifier.<init>("1.2.840.113549.1.1.2");
      var10000.put("MD2WITHRSAENCRYPTION", var0);
      var10000 = algorithms;
      var0 = new DERObjectIdentifier.<init>("1.2.840.113549.1.1.2");
      var10000.put("MD2WITHRSA", var0);
      var10000 = algorithms;
      var0 = new DERObjectIdentifier.<init>("1.2.840.113549.1.1.4");
      var10000.put("MD5WITHRSAENCRYPTION", var0);
      var10000 = algorithms;
      var0 = new DERObjectIdentifier.<init>("1.2.840.113549.1.1.4");
      var10000.put("MD5WITHRSA", var0);
      var10000 = algorithms;
      var0 = new DERObjectIdentifier.<init>("1.2.840.113549.1.1.4");
      var10000.put("RSAWITHMD5", var0);
      var10000 = algorithms;
      var0 = new DERObjectIdentifier.<init>("1.2.840.113549.1.1.5");
      var10000.put("SHA1WITHRSAENCRYPTION", var0);
      var10000 = algorithms;
      var0 = new DERObjectIdentifier.<init>("1.2.840.113549.1.1.5");
      var10000.put("SHA1WITHRSA", var0);
      var0 = PKCSObjectIdentifiers.sha224WithRSAEncryption;
      algorithms.put("SHA224WITHRSAENCRYPTION", var0);
      algorithms.put("SHA224WITHRSA", var0);
      DERObjectIdentifier var1 = PKCSObjectIdentifiers.sha256WithRSAEncryption;
      algorithms.put("SHA256WITHRSAENCRYPTION", var1);
      algorithms.put("SHA256WITHRSA", var1);
      DERObjectIdentifier var2 = PKCSObjectIdentifiers.sha384WithRSAEncryption;
      algorithms.put("SHA384WITHRSAENCRYPTION", var2);
      algorithms.put("SHA384WITHRSA", var2);
      DERObjectIdentifier var3 = PKCSObjectIdentifiers.sha512WithRSAEncryption;
      algorithms.put("SHA512WITHRSAENCRYPTION", var3);
      algorithms.put("SHA512WITHRSA", var3);
      DERObjectIdentifier var4 = PKCSObjectIdentifiers.id_RSASSA_PSS;
      algorithms.put("SHA1WITHRSAANDMGF1", var4);
      algorithms.put("SHA224WITHRSAANDMGF1", var4);
      algorithms.put("SHA256WITHRSAANDMGF1", var4);
      algorithms.put("SHA384WITHRSAANDMGF1", var4);
      algorithms.put("SHA512WITHRSAANDMGF1", var4);
      var10000 = algorithms;
      var4 = new DERObjectIdentifier.<init>("1.2.840.113549.1.1.5");
      var10000.put("RSAWITHSHA1", var4);
      var10000 = algorithms;
      var4 = new DERObjectIdentifier.<init>("1.3.36.3.3.1.2");
      var10000.put("RIPEMD160WITHRSAENCRYPTION", var4);
      var10000 = algorithms;
      var4 = new DERObjectIdentifier.<init>("1.3.36.3.3.1.2");
      var10000.put("RIPEMD160WITHRSA", var4);
      var10000 = algorithms;
      var4 = new DERObjectIdentifier.<init>("1.2.840.10040.4.3");
      var10000.put("SHA1WITHDSA", var4);
      var10000 = algorithms;
      var4 = new DERObjectIdentifier.<init>("1.2.840.10040.4.3");
      var10000.put("DSAWITHSHA1", var4);
      var4 = NISTObjectIdentifiers.dsa_with_sha224;
      algorithms.put("SHA224WITHDSA", var4);
      DERObjectIdentifier var5 = NISTObjectIdentifiers.dsa_with_sha256;
      algorithms.put("SHA256WITHDSA", var5);
      DERObjectIdentifier var6 = X9ObjectIdentifiers.ecdsa_with_SHA1;
      algorithms.put("SHA1WITHECDSA", var6);
      DERObjectIdentifier var7 = X9ObjectIdentifiers.ecdsa_with_SHA224;
      algorithms.put("SHA224WITHECDSA", var7);
      DERObjectIdentifier var8 = X9ObjectIdentifiers.ecdsa_with_SHA256;
      algorithms.put("SHA256WITHECDSA", var8);
      DERObjectIdentifier var9 = X9ObjectIdentifiers.ecdsa_with_SHA384;
      algorithms.put("SHA384WITHECDSA", var9);
      DERObjectIdentifier var10 = X9ObjectIdentifiers.ecdsa_with_SHA512;
      algorithms.put("SHA512WITHECDSA", var10);
      algorithms.put("ECDSAWITHSHA1", var6);
      DERObjectIdentifier var11 = CryptoProObjectIdentifiers.gostR3411_94_with_gostR3410_94;
      algorithms.put("GOST3411WITHGOST3410", var11);
      algorithms.put("GOST3410WITHGOST3411", var11);
      DERObjectIdentifier var12 = CryptoProObjectIdentifiers.gostR3411_94_with_gostR3410_2001;
      algorithms.put("GOST3411WITHECGOST3410", var12);
      algorithms.put("GOST3411WITHECGOST3410-2001", var12);
      algorithms.put("GOST3411WITHGOST3410-2001", var12);
      oids.put(new DERObjectIdentifier("1.2.840.113549.1.1.5"), "SHA1WITHRSA");
      oids.put(var0, "SHA224WITHRSA");
      oids.put(var1, "SHA256WITHRSA");
      oids.put(var2, "SHA384WITHRSA");
      oids.put(var3, "SHA512WITHRSA");
      oids.put(var11, "GOST3411WITHGOST3410");
      oids.put(var12, "GOST3411WITHECGOST3410");
      oids.put(new DERObjectIdentifier("1.2.840.113549.1.1.4"), "MD5WITHRSA");
      oids.put(new DERObjectIdentifier("1.2.840.113549.1.1.2"), "MD2WITHRSA");
      oids.put(new DERObjectIdentifier("1.2.840.10040.4.3"), "SHA1WITHDSA");
      oids.put(var6, "SHA1WITHECDSA");
      oids.put(var7, "SHA224WITHECDSA");
      oids.put(var8, "SHA256WITHECDSA");
      oids.put(var9, "SHA384WITHECDSA");
      oids.put(var10, "SHA512WITHECDSA");
      oids.put(OIWObjectIdentifiers.sha1WithRSA, "SHA1WITHRSA");
      oids.put(OIWObjectIdentifiers.dsaWithSHA1, "SHA1WITHDSA");
      oids.put(var4, "SHA224WITHDSA");
      oids.put(var5, "SHA256WITHDSA");
      keyAlgorithms.put(PKCSObjectIdentifiers.rsaEncryption, "RSA");
      keyAlgorithms.put(X9ObjectIdentifiers.id_dsa, "DSA");
      noParams.add(var6);
      noParams.add(var7);
      noParams.add(var8);
      noParams.add(var9);
      noParams.add(var10);
      noParams.add(X9ObjectIdentifiers.id_dsa_with_sha1);
      noParams.add(var4);
      noParams.add(var5);
      noParams.add(var11);
      noParams.add(var12);
      AlgorithmIdentifier var13;
      var13 = new AlgorithmIdentifier.<init>(OIWObjectIdentifiers.idSHA1, new DERNull());
      params.put("SHA1WITHRSAANDMGF1", creatPSSParams(var13, 20));
      var13 = new AlgorithmIdentifier.<init>(NISTObjectIdentifiers.id_sha224, new DERNull());
      params.put("SHA224WITHRSAANDMGF1", creatPSSParams(var13, 28));
      var13 = new AlgorithmIdentifier.<init>(NISTObjectIdentifiers.id_sha256, new DERNull());
      params.put("SHA256WITHRSAANDMGF1", creatPSSParams(var13, 32));
      var13 = new AlgorithmIdentifier.<init>(NISTObjectIdentifiers.id_sha384, new DERNull());
      params.put("SHA384WITHRSAANDMGF1", creatPSSParams(var13, 48));
      var13 = new AlgorithmIdentifier.<init>(NISTObjectIdentifiers.id_sha512, new DERNull());
      params.put("SHA512WITHRSAANDMGF1", creatPSSParams(var13, 64));
   }

   private static X509Name convertName(X500Principal name) {
      try {
         return new X509Principal(name.getEncoded());
      } catch (IOException var1) {
         throw new IllegalArgumentException("can't convert name");
      }
   }

   private static RSASSAPSSparams creatPSSParams(AlgorithmIdentifier hashAlgId, int saltSize) {
      AlgorithmIdentifier var10002 = hashAlgId;
      AlgorithmIdentifier var2;
      var2 = new AlgorithmIdentifier.<init>(PKCSObjectIdentifiers.id_mgf1, hashAlgId);
      DERInteger hashAlgId1;
      hashAlgId1 = new DERInteger.<init>(saltSize);
      DERInteger saltSize1;
      saltSize1 = new DERInteger.<init>(1);
      return new RSASSAPSSparams(var10002, var2, hashAlgId1, saltSize1);
   }

   private static String getDigestAlgName(DERObjectIdentifier digestAlgOID) {
      if (PKCSObjectIdentifiers.md5.equals(digestAlgOID)) {
         return "MD5";
      } else if (OIWObjectIdentifiers.idSHA1.equals(digestAlgOID)) {
         return "SHA1";
      } else if (NISTObjectIdentifiers.id_sha224.equals(digestAlgOID)) {
         return "SHA224";
      } else if (NISTObjectIdentifiers.id_sha256.equals(digestAlgOID)) {
         return "SHA256";
      } else if (NISTObjectIdentifiers.id_sha384.equals(digestAlgOID)) {
         return "SHA384";
      } else if (NISTObjectIdentifiers.id_sha512.equals(digestAlgOID)) {
         return "SHA512";
      } else if (TeleTrusTObjectIdentifiers.ripemd128.equals(digestAlgOID)) {
         return "RIPEMD128";
      } else if (TeleTrusTObjectIdentifiers.ripemd160.equals(digestAlgOID)) {
         return "RIPEMD160";
      } else if (TeleTrusTObjectIdentifiers.ripemd256.equals(digestAlgOID)) {
         return "RIPEMD256";
      } else {
         return CryptoProObjectIdentifiers.gostR3411.equals(digestAlgOID) ? "GOST3411" : digestAlgOID.getId();
      }
   }

   static String getSignatureName(AlgorithmIdentifier sigAlgId) {
      DEREncodable var1;
      if ((var1 = sigAlgId.getParameters()) != null && !DERNull.INSTANCE.equals(var1) && sigAlgId.getObjectId().equals(PKCSObjectIdentifiers.id_RSASSA_PSS)) {
         RSASSAPSSparams sigAlgId1 = RSASSAPSSparams.getInstance(var1);
         return getDigestAlgName(sigAlgId1.getHashAlgorithm().getObjectId()) + "withRSAandMGF1";
      } else {
         return sigAlgId.getObjectId().getId();
      }
   }

   private static ASN1Sequence toDERSequence(byte[] bytes) {
      try {
         return (ASN1Sequence)(new ASN1InputStream(bytes)).readObject();
      } catch (Exception var1) {
         throw new IllegalArgumentException("badly encoded request");
      }
   }

   public PKCS10CertificationRequest(X509Name subject, PublicKey key, ASN1Set attributes, PrivateKey signingKey, String provider) {
      this("SHA1WITHRSAENCRYPTION", subject, key, attributes, signingKey, provider);
   }

   public PKCS10CertificationRequest(ASN1Sequence sequence) {
      super(sequence);
   }

   public PKCS10CertificationRequest(byte[] bytes) {
      super(toDERSequence(bytes));
   }

   public PKCS10CertificationRequest(String signatureAlgorithm, X500Principal subject, PublicKey key, ASN1Set attributes, PrivateKey signingKey) {
      this(signatureAlgorithm, convertName(subject), key, attributes, signingKey, "INFOSEC");
   }

   public PKCS10CertificationRequest(String signatureAlgorithm, X500Principal subject, PublicKey key, ASN1Set attributes, PrivateKey signingKey, String provider) {
      this(signatureAlgorithm, convertName(subject), key, attributes, signingKey, provider);
   }

   public PKCS10CertificationRequest(String signatureAlgorithm, X509Name subject, PublicKey key, ASN1Set attributes, PrivateKey signingKey) {
      this(signatureAlgorithm, subject, key, attributes, signingKey, "INFOSEC");
   }

   public PKCS10CertificationRequest(String signatureAlgorithm, X509Name subject, PublicKey key, ASN1Set attributes, PrivateKey signingKey, String provider) {
      String var7 = Strings.toUpperCase(signatureAlgorithm);
      DERObjectIdentifier var8;
      if ((var8 = (DERObjectIdentifier)algorithms.get(var7)) != null) {
         if (subject == null) {
            throw new IllegalArgumentException("subject must not be null");
         } else if (key != null) {
            AlgorithmIdentifier var20;
            if (noParams.contains(var8)) {
               var20 = new AlgorithmIdentifier.<init>(var8);
               super.sigAlgId = var20;
            } else if (params.containsKey(var7)) {
               super.sigAlgId = new AlgorithmIdentifier(var8, (DEREncodable)params.get(var7));
            } else {
               var20 = new AlgorithmIdentifier.<init>(var8, (DEREncodable)null);
               super.sigAlgId = var20;
            }

            String var10001 = signatureAlgorithm;
            PKCS10CertificationRequest var10003 = this;
            byte[] signatureAlgorithm1 = key.getEncoded();
            ByteArrayInputStream key1;
            key1 = new ByteArrayInputStream.<init>(signatureAlgorithm1);
            ASN1InputStream signatureAlgorithm2;
            signatureAlgorithm2 = new ASN1InputStream.<init>(key1);

            CertificationRequestInfo var10004;
            CertificationRequestInfo var10005;
            boolean var21;
            X509Name var10006;
            SubjectPublicKeyInfo var10007;
            try {
               var10004 = new CertificationRequestInfo;
               var10005 = var10004;
               var10006 = subject;
               var10007 = new SubjectPublicKeyInfo;
            } catch (IOException var13) {
               var21 = false;
               throw new IllegalArgumentException("can't encode public key");
            }

            SubjectPublicKeyInfo var10008 = var10007;

            try {
               var10008.<init>((ASN1Sequence)signatureAlgorithm2.readObject());
               var10005.<init>(var10006, var10007, attributes);
               var10003.reqInfo = var10004;
            } catch (IOException var12) {
               var21 = false;
               throw new IllegalArgumentException("can't encode public key");
            }

            Signature signatureAlgorithm3;
            Signature var22 = signatureAlgorithm3 = Signature.getInstance(var10001, provider);
            var22.initSign(signingKey);

            label54: {
               Exception var10000;
               label75: {
                  ByteArrayOutputStream var10002;
                  try {
                     var10002 = new ByteArrayOutputStream;
                  } catch (Exception var11) {
                     var10000 = var11;
                     var21 = false;
                     break label75;
                  }

                  ByteArrayOutputStream subject1;
                  ByteArrayOutputStream var23 = subject1 = var10002;

                  DEROutputStream var24;
                  try {
                     var23.<init>();
                     var24 = new DEROutputStream;
                  } catch (Exception var10) {
                     var10000 = var10;
                     var21 = false;
                     break label75;
                  }

                  DEROutputStream var25 = var24;

                  try {
                     var25.<init>(subject1);
                     var24.writeObject(super.reqInfo);
                     var22.update(var10002.toByteArray());
                     break label54;
                  } catch (Exception var9) {
                     var10000 = var9;
                     var21 = false;
                  }
               }

               Exception var14 = var10000;
               throw new IllegalArgumentException("exception encoding TBS cert request - " + var14);
            }

            super.sigBits = new DERBitString(signatureAlgorithm3.sign());
         } else {
            throw new IllegalArgumentException("public key must not be null");
         }
      } else {
         throw new IllegalArgumentException("Unknown signature type requested");
      }
   }

   private void setSignatureParameters(Signature param1, DEREncodable param2) {
      // $FF: Couldn't be decompiled
   }

   public byte[] getEncoded() {
      ByteArrayOutputStream var1;
      ByteArrayOutputStream var10000 = var1 = new ByteArrayOutputStream;
      var10000.<init>();
      PKCS10CertificationRequest var10002 = this;
      DEROutputStream var10001 = new DEROutputStream(var1);

      try {
         var10001.writeObject(var10002);
      } catch (IOException var2) {
         throw new RuntimeException(var2.toString());
      }

      return var10000.toByteArray();
   }

   public PublicKey getPublicKey() {
      return this.getPublicKey("INFOSEC");
   }

   public PublicKey getPublicKey(String provider) {
      SubjectPublicKeyInfo var9;
      SubjectPublicKeyInfo var10000 = var9 = super.reqInfo.getSubjectPublicKeyInfo();
      X509EncodedKeySpec var2;
      var2 = new X509EncodedKeySpec.<init>((new DERBitString(var9)).getBytes());
      AlgorithmIdentifier var10;
      AlgorithmIdentifier var11 = var10 = var10000.getAlgorithmId();

      boolean var10001;
      NoSuchAlgorithmException var3;
      try {
         try {
            return KeyFactory.getInstance(var11.getObjectId().getId(), provider).generatePublic(var2);
         } catch (NoSuchAlgorithmException var7) {
            var3 = var7;
         }
      } catch (InvalidKeySpecException var8) {
         var10001 = false;
         throw new InvalidKeyException("error decoding public key");
      }

      Object var12;
      try {
         var12 = keyAlgorithms.get(var10.getObjectId());
      } catch (InvalidKeySpecException var6) {
         var10001 = false;
         throw new InvalidKeyException("error decoding public key");
      }

      if (var12 != null) {
         try {
            return KeyFactory.getInstance((String)keyAlgorithms.get(var10.getObjectId()), provider).generatePublic(var2);
         } catch (InvalidKeySpecException var4) {
            var10001 = false;
         }
      } else {
         try {
            throw var3;
         } catch (InvalidKeySpecException var5) {
            var10001 = false;
         }
      }

      throw new InvalidKeyException("error decoding public key");
   }

   public boolean verify() {
      return this.verify("INFOSEC");
   }

   public boolean verify(PublicKey pubKey, String provider) {
      Signature provider1;
      label44: {
         Signature var10000;
         try {
            var10000 = Signature.getInstance(getSignatureName(super.sigAlgId), provider);
         } catch (NoSuchAlgorithmException var7) {
            if (oids.get(super.sigAlgId.getObjectId()) != null) {
               provider1 = Signature.getInstance((String)oids.get(super.sigAlgId.getObjectId()), provider);
               break label44;
            }

            throw var7;
         }

         provider1 = var10000;
      }

      Signature var10002 = provider1;
      this.setSignatureParameters(provider1, super.sigAlgId.getParameters());
      provider1.initVerify(pubKey);

      Exception var11;
      label47: {
         boolean var10001;
         ByteArrayOutputStream var10003;
         try {
            var10003 = new ByteArrayOutputStream;
         } catch (Exception var6) {
            var11 = var6;
            var10001 = false;
            break label47;
         }

         ByteArrayOutputStream pubKey1;
         ByteArrayOutputStream var10004 = pubKey1 = var10003;

         DEROutputStream var12;
         try {
            var10004.<init>();
            var12 = new DEROutputStream;
         } catch (Exception var5) {
            var11 = var5;
            var10001 = false;
            break label47;
         }

         DEROutputStream var10005 = var12;

         try {
            var10005.<init>(pubKey1);
            var12.writeObject(super.reqInfo);
            var10002.update(var10003.toByteArray());
            return provider1.verify(super.sigBits.getBytes());
         } catch (Exception var4) {
            var11 = var4;
            var10001 = false;
         }
      }

      Exception var8 = var11;
      throw new SignatureException("exception encoding TBS cert request - " + var8);
   }

   public boolean verify(String provider) {
      return this.verify(this.getPublicKey(provider), provider);
   }
}
